package Armadito::Agent::Task::Scan;

use strict;
use warnings;
use base 'Armadito::Agent::Task';

use FusionInventory::Agent::Config;
use FusionInventory::Agent::Logger;
use Data::Dumper;
use JSON;

sub isEnabled {
    my ($self) = @_;

    return 1;
}

sub new {
    my ($class, %params) = @_;

    my $self = $class->SUPER::new(%params);

    if ($params{debug}) {
        $self->{debug} = 1;
    }

	my $task = {
		name => "Scan",
		antivirus => ""
	};

	$self->{jobj}->{task} = $task;

    return $self;
}

sub _handleResponse {
    my ($self, $response) = @_;

    $self->{logger}->info("Successful Response : ".$response->content());
    my $obj =  from_json($response->content(), { utf8  => 1 });
    $self->{logger}->info(Dumper($obj));

    return $self;
}

sub _handleError {
    my ($self, $response) = @_;

    $self->{logger}->info("Error Response : ".$response->content());
    my $obj =  from_json($response->content(), { utf8  => 1 });
    $self->{logger}->error(Dumper($obj));

    return $self;
}

sub run {
    my ( $self, %params ) = @_;

    $self = $self->SUPER::run(%params);

    return $self;
}

1;

__END__

=head1 NAME

Armadito::Agent::Task::Scan - Scan Task base class

=head1 DESCRIPTION

This task inherits from L<Armadito::Agent::Task>. Launch a Antivirus on-demand scan and send a brief report to GPLI server Armadito plugin.

=head1 FUNCTIONS

=head2 isEnabled ( $self )

Returns true if the task is enabled.

=head2 run ( $self, %params )

Run the task.

=head2 new ( $self, %params )

Instanciate Task.

